@@ -12,6 +12,14 @@ from django.utils.translation import ugettext_lazy as _
 BASE_PATH = __Path(__file__).resolve().parent.parent.parent
 
 
+# SECURITY WARNING: don't run with debug turned on in production!
+DEBUG = False
+
+# Serve static/media files by Django?
+# In production Caddy should serve this!
+SERVE_FILES = False
+
+
 # SECURITY WARNING: keep the secret key used in production secret!
 __SECRET_FILE = __Path(BASE_PATH, 'secret.txt').resolve()
 if not __SECRET_FILE.is_file():
@@ -37,6 +45,7 @@ INSTALLED_APPS = [
     'import_export',  # https://github.com/django-import-export/django-import-export
     'dbbackup',  # https://github.com/django-dbbackup/django-dbbackup
     'ckeditor',  # https://github.com/django-ckeditor/django-ckeditor
+    'ckeditor_uploader',  # https://github.com/django-ckeditor/django-ckeditor
     'reversion',  # https://github.com/etianen/django-reversion
     'reversion_compare',  # https://github.com/jedie/django-reversion-compare
     'tagulous',  # https://github.com/radiac/django-tagulous
@@ -132,34 +141,131 @@ DBBACKUP_STORAGE_OPTIONS = {'location': str(__Path(BASE_PATH, 'backups'))}
 # django-ckeditor
 
 CKEDITOR_BASEPATH = STATIC_URL + 'ckeditor/ckeditor/'
-CKEDITOR_UPLOAD_PATH = 'uploads/'
-CKEDITOR_FILENAME_GENERATOR = 'utils.get_filename'
-CKEDITOR_CONFIGS = {
-    'ItemModel.description': {
-        'skin': 'moono-lisa',
-        'removeButtons': 'Language',
+CKEDITOR_FILENAME_GENERATOR = 'inventory.ckeditor_upload.get_filename'
+CKEDITOR_DEFAULT_CONFIG = {
+    'skin': 'moono-lisa',
+    'removeButtons': 'Language,Cut,Copy,Paste,Undo,Redo,Anchor',
 
-        # plugins are here: site-packages/ckeditor/static/ckeditor/ckeditor/plugins
-        'removePlugins': 'wsc,div,flash,iframe,bidi',
-        'toolbar': 'full',
-        'height': '25em',
-        'width': '100%',
-        'filebrowserWindowWidth': 940,
-        'filebrowserWindowHeight': 725,
-    },
-    'LocationModel.description': {
-        'skin': 'moono-lisa',
-        'removeButtons': 'Language',
-
-        # plugins are here: site-packages/ckeditor/static/ckeditor/ckeditor/plugins
-        'removePlugins': 'wsc,div,flash,iframe,bidi',
-        'toolbar': 'full',
-        'height': '25em',
-        'width': '100%',
-        'filebrowserWindowWidth': 940,
-        'filebrowserWindowHeight': 725,
-    }
+    # plugins are here: .../site-packages/ckeditor/static/ckeditor/ckeditor/plugins
+    # and here: https://github.com/ckeditor/ckeditor4/tree/major/plugins
+    # See also: .../site-packages/ckeditor/static/ckeditor/ckeditor/build-config.js
+    'removePlugins': (
+        # Generated with .../dev-scripts/ckeditor_info.py
+        'a11yhelp',
+        'about',
+        'adobeair',
+        'ajax',
+        'autoembed',
+        # 'autogrow',
+        'autolink',
+        # 'basicstyles',
+        'bbcode',
+        'bidi',
+        # 'blockquote',
+        'clipboard',
+        'codesnippet',
+        'codesnippetgeshi',
+        # 'colorbutton',
+        # 'colordialog',
+        'contextmenu',
+        'copyformatting',
+        'devtools',
+        'dialog',
+        'dialogadvtab',
+        'div',
+        'divarea',
+        'docprops',
+        # 'elementspath',
+        'embed',
+        'embedbase',
+        'embedsemantic',
+        'enterkey',
+        # 'entities',
+        # 'filebrowser',
+        # 'filetools',
+        'find',
+        'flash',
+        # 'floatingspace',
+        # 'font',
+        # 'format',
+        'forms',
+        # 'horizontalrule',
+        'htmlwriter',
+        'iframe',
+        'iframedialog',
+        # 'image',
+        # 'image2',
+        # 'indentblock',
+        # 'indentlist',
+        # 'justify',
+        'language',
+        # 'lineutils',
+        # 'link',
+        # 'list',
+        # 'liststyle',
+        'magicline',
+        'mathjax',
+        # 'maximize',
+        # 'menubutton',
+        'newpage',
+        'notification',
+        'notificationaggregator',
+        'pagebreak',
+        'pastefromgdocs',
+        'pastefromword',
+        'pastetext',
+        'pastetools',
+        'placeholder',
+        'preview',
+        'print',
+        # 'removeformat',
+        # 'resize',
+        'save',
+        'scayt',
+        'selectall',
+        'sharedspace',
+        # 'showblocks',
+        # 'showborders',
+        'smiley',
+        'sourcearea',
+        'sourcedialog',
+        'specialchar',
+        'stylescombo',
+        'stylesheetparser',
+        'tab',
+        # 'table',
+        # 'tableresize',
+        # 'tableselection',
+        # 'tabletools',
+        'templates',
+        # 'toolbar',
+        'uicolor',
+        # 'undo',
+        # 'uploadimage',
+        # 'uploadwidget',
+        'widget',
+        'wsc',
+        # 'wysiwygarea',
+        'xml',
+    ),
+    'toolbar': 'full',
+    'height': '25em',
+    'width': '100%',
+    'filebrowserWindowWidth': 940,
+    'filebrowserWindowHeight': 725,
 }
+CKEDITOR_CONFIGS = {
+    'ItemModel.description': CKEDITOR_DEFAULT_CONFIG,
+    'LocationModel.description': CKEDITOR_DEFAULT_CONFIG
+}
+CKEDITOR_RESTRICT_BY_USER = True
+CKEDITOR_RESTRICT_BY_DATE = True
+CKEDITOR_UPLOAD_PATH = 'uploads/'
+CKEDITOR_IMAGE_BACKEND = 'pillow'
+CKEDITOR_THUMBNAIL_SIZE = (300, 300)
+CKEDITOR_IMAGE_QUALITY = 40
+CKEDITOR_BROWSE_SHOW_DIRS = True
+CKEDITOR_ALLOW_NONIMAGE_FILES = True
 
 # _____________________________________________________________________________
 # http://radiac.net/projects/django-tagulous/documentation/installation/#settings
