@@ -15,6 +15,11 @@ from inventory_project.settings.base import *  # noqa
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = True
 
+
+# Serve static/media files for local development:
+SERVE_FILES = True
+
+
 # Disable caches:
 CACHES = {'default': {'BACKEND': 'django.core.cache.backends.dummy.DummyCache'}}
 
